AuthState class

_onLogin & _onLogout are called only one time after sign in or sign out

Inheritance

Constructors

AuthState({int splashScreenDurationMillis = 0, bool autoSignInAnonymously = false, Future onZombieGenerated(String)?})

Properties

actionsAfterLogIn Future Function(AuthMethod, User?)?
getter/setter pair
actionsBeforeLogOut Future Function(User?)?
getter/setter pair
authStatus AuthStatus
no setter
autoSignInAnonymously bool
getter/setter pair
email String?
no setter
firebaseUser → User?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAnonymous bool
no setter
name String?
no setter
onZombieGenerated Future Function(String)?
getter/setter pair
photoUrl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashScreenDurationMillis int
final
uid String?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
changeName(String name) Future<void>
changePhotoUrl(String photoUrl) Future<void>
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
isEmailRegistered(String e) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resetPassword(dynamic email) Future<void>
CHANGES///
sendEmailVerification() Future<void>
signInAnonymous() Future<User?>
signInApple() Future<User?>
signInGoogle() Future<User?>
signInWithEmail(String email, String password) Future<User?>
signOut({bool shouldNotify = true, bool canReauthenticate = true}) Future<void>
signUpWithEmail(String email, String password, String name) Future<User?>
supportsAppleSignIn() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited